@@ -20,6 +20,7 @@ import collections
 import email
 import imaplib
 import re
+import csv
 
 # unicode in py2, str in py3
 from .six.moves.urllib.request import (build_opener, HTTPCookieProcessor)
@@ -35,7 +36,7 @@ from .gziphttp import GZipProcessor
 
 from . import adapters
 from .configurable import Configuration
-from .exceptions import UnknownSite
+from .exceptions import UnknownSite, FetchEmailFailed
 
 def get_urls_from_page(url,configuration=None,normalize=False):
 
@@ -136,7 +137,10 @@ def get_urls_from_text(data,configuration=None,normalize=False,email=False):
     if not configuration:
         configuration = Configuration(["test1.com"],"EPUB",lightweight=True)
 
-    for href in re.findall('http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+', data):
+    for href in re.findall('\(?http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+\)?', data):
+        ## detect and remove ()s around URL ala markdown.
+        if href[0] == '(' and href[-1] == ')':
+            href = href[1:-1]
         href = cleanup_url(href,email)
         try:
             adapter = adapters.getAdapter(configuration,href)
@@ -192,7 +196,10 @@ def cleanup_url(href,email=False):
         ## xenforo emails, toss unread and page/post urls.  Emails are
         ## only sent for thread updates, I believe.  Email only so
         ## get_urls_from_page can still get post URLs.
-        href = re.sub(r"/(unread|page-\d+)?(#post-\d+)?",r"/",href)
+        href = re.sub(r"/(unread|page-\d+)?(#post-\d+)?(\?new=1)?",r"/",href)
+    elif email and 'sufficientvelocity' in href and '/posts/' in href:
+        ## SV emails now use /posts/ instead of #post-
+        href = ""
     elif 'click' in href and 'royalroad' in href: # they've changed the domain at least once
         # logger.debug(href)
         from .six.moves.urllib.request import build_opener
@@ -208,15 +215,40 @@ def get_urls_from_imap(srv,user,passwd,folder,markread=True):
 
     # logger.debug("get_urls_from_imap srv:(%s)"%srv)
     mail = imaplib.IMAP4_SSL(srv)
-    mail.login(user, passwd)
-    mail.list()
+    status = mail.login(user, passwd)
+    if status[0] != 'OK':
+        raise FetchEmailFailed("Failed to login to mail server")
     # Out: list of "folders" aka labels in gmail.
-    mail.select('"%s"'%folder) # Needs to be quoted incase there are
-                               # spaces, etc.  imaplib doesn't
-                               # correctly quote folders with spaces.
-                               # However, it does check and won't
-                               # quote strings that already start and
-                               # end with ", so this is safe.
+    status = mail.list()
+    # logger.debug(status)
+
+    folders = []
+    try:
+        for f in status[1]:
+            m = re.match(r'^\(.*\) "?."? "?(?P<folder>.+?)"?$',ensure_str(f))
+            if m:
+                folders.append(m.group("folder").replace("\\",""))
+                # logger.debug(folders[-1])
+            else:
+                logger.warn("Failed to parse IMAP folder line(%s)"%ensure_str(f))
+    except:
+        folders = []
+        logger.warning("Failed to parse IMAP folder list, continuing without list.")
+
+    if status[0] != 'OK':
+        raise FetchEmailFailed("Failed to list folders on mail server")
+
+    # Needs to be quoted incase there are spaces, etc.  imaplib
+    # doesn't correctly quote folders with spaces.  However, it does
+    # check and won't quote strings that already start and end with ",
+    # so this is safe.  There may be other chars than " that need escaping.
+    status = mail.select('"%s"'%folder.replace('"','\\"'))
+    if status[0] != 'OK':
+        logger.debug(status)
+        if folders:
+            raise FetchEmailFailed("Failed to select folder(%s) on mail server (folder list:%s)"%(folder,folders))
+        else:
+            raise FetchEmailFailed("Failed to select folder(%s) on mail server"%folder)
 
     result, data = mail.uid('search', None, "UNSEEN")
 
